## Installing Blender

We use Blender 2.82 for mesh processing. You can run:
```
./install_blender.sh
```
to install Blender version 2.82.

Check if installation is correct by calling:
```
blender
```
in a command line window. If the command fails, it's likely that ```$PATH``` was set incorrectly in ```~/.bashrc```. 